@@ -32,7 +32,10 @@ int main() {
       printf("AVX512SPR\n");
       break;
     case 10:
-      printf("AVX10_2\n");
+      printf("AVX512GNR\n");
+      break;
+    case 11:
+      printf("AVX10_2DMR\n");
       break;
     default:
       printf("Unknown ISA\n");
